// -*- Mode: C++; -*-
#include <qmultilinedit.h>
#include <qwidget.h>

#ifndef _edit_h
#define _edit_h

class CEdit : public virtual QTextEdit
{
    Q_OBJECT
public:
    CEdit (QWidget * parent=0, const char * name=0 );
    virtual ~CEdit();

signals:
    void cursormove();

protected slots:
    virtual void keyPressEvent(QKeyEvent*e);
    virtual void focusInEvent(QFocusEvent*e);
    virtual void mouseReleaseEvent(QMouseEvent*e);
};

#endif
